@@ -3,13 +3,15 @@ package Padre::Document::PIR;
 use 5.008;
 use strict;
 use warnings;
+
 use Carp ();
 use Params::Util '_INSTANCE';
+use Padre::Logger;
 use Padre::Document ();
-use Padre::Util ();
+use Padre::Util     ();
 use Padre::Constant;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 our @ISA     = 'Padre::Document';
 
 # Naive way to parse and colorize pir files
@@ -17,14 +19,14 @@ sub colorize {
 	my ( $self, $first ) = @_;
 
 	my $doc = Padre::Current->document;
-	Padre::Util::debug(__PACKAGE__ . " colorize called (self: $self) (doc: $doc)");
+	TRACE( __PACKAGE__ . " colorize called (self: $self) (doc: $doc)" ) if DEBUG;
 
 	$doc->remove_color;
 
 	my $editor = $doc->editor;
-	Padre::Util::debug('done');
-	my $text   = $doc->text_get;
-	Padre::Util::debug("text to colorize: $text");
+	TRACE('done') if DEBUG;
+	my $text = $doc->text_get;
+	TRACE("text to colorize: $text") if DEBUG;
 
 	#	my @lines = split /\n/, $text;
 	#	foreach my $line (@lines) {
@@ -46,7 +48,7 @@ sub colorize {
 			my $end    = pos($text);
 			my $length = length($&);
 			my $start  = $end - $length;
-			Padre::Util::debug("start: $start, length: $length, end: $end");
+			TRACE("start: $start, length: $length, end: $end") if DEBUG;
 			$editor->StartStyling( $start, $color );
 			$editor->SetStyling( $length, $color );
 		}
@@ -60,7 +62,7 @@ sub get_command {
 	my ($self) = @_;
 
 	return if not $ENV{PARROT_DIR};
-	my $parrot = "$ENV{PARROT_DIR}/parrot" . (Padre::Constant::WIN32 ? '.exe' : '');
+	my $parrot = "$ENV{PARROT_DIR}/parrot" . ( Padre::Constant::WIN32 ? '.exe' : '' );
 
 	return if not -e $parrot;
 	my $filename = $self->filename;
@@ -73,24 +75,44 @@ sub pir2pbc {
 	my ($self) = @_;
 
 	return if not $ENV{PARROT_DIR};
-	my $parrot = "$ENV{PARROT_DIR}/parrot" . (Padre::Constant::WIN32 ? '.exe' : '');
+	my $parrot = "$ENV{PARROT_DIR}/parrot" . ( Padre::Constant::WIN32 ? '.exe' : '' );
 
 	return if not -e $parrot;
 	my $filename = $self->filename;
 	return if not $filename or $filename !~ /\.pir$/i;
-	
-	
-	my $outfile = substr($filename, 0, -3) . 'pbc';
+
+
+	my $outfile = substr( $filename, 0, -3 ) . 'pbc';
 
 	my $cmd = "$parrot -o $outfile $filename";
+
 	#my $main = Padre->ide->wx->main;
 	#$main->message($cmd);
 	system $cmd;
 }
 
+sub get_help_provider {
+	require Padre::HelpProvider::PIR;
+	return Padre::HelpProvider::PIR->new;
+}
+
 1;
 
-# Copyright 2008-2009 Gabor Szabo.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
+__END__
+
+=head1 NAME
+
+Padre::Plugin::Document::PIR - Padre PIR Document
+
+=head1 AUTHOR
+
+Gabor Szabo L<http://szabgab.com/>
+
+Ahmad M. Zawawi C<< <ahmad.zawawi at gmail.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2008-2010 Padre Developers as in Parrot.pm
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
