@@ -2,7 +2,9 @@ package Padre::Plugin::Parrot::HL;
 use strict;
 use warnings;
 
-our $VERSION = '0.26';
+use Padre::Wx ();
+
+our $VERSION = '0.27';
 
 # colorize timer to make sure that colorize tasks are scheduled properly...
 my $COLORIZE_TIMER;
@@ -13,30 +15,33 @@ sub colorize {
 	my $self = shift;
 	my @args = @_;
 
-	my ($pbc, $path) = $self->pbc_path;
-	
+	my ( $pbc, $path ) = $self->pbc_path;
+
 	#print "PP::HL: $self  $pbc  $path\n";
 
-	my $doc = Padre::Current->document;
+	my $doc      = Padre::Current->document;
 	my $timer_id = Wx::NewId();
-	my $main = Padre->ide->wx->main;
-	$COLORIZE_TIMER = Wx::Timer->new($main, $timer_id);
+	my $main     = Padre->ide->wx->main;
+	$COLORIZE_TIMER = Wx::Timer->new( $main, $timer_id );
 	Wx::Event::EVT_TIMER(
-		$main, $timer_id, 
-		sub { 
+		$main,
+		$timer_id,
+		sub {
 			require Padre::Plugin::Parrot::ColorizeTask;
 			my $task = Padre::Plugin::Parrot::ColorizeTask->new(
-				text => $doc->text_with_one_nl,
-				editor => $doc->editor,
+				text     => $doc->text_with_one_nl,
+				editor   => $doc->editor,
 				document => $doc,
-				pbc => $pbc,
-				path => $path,
-				);
+				pbc      => $pbc,
+				path     => $path,
+			);
+
 			# hand off to the task manager
 			$task->schedule();
 
 			# and let us schedule that it is running properly or not
-			if($task->is_broken) {
+			if ( $task->is_broken ) {
+
 				# let us reschedule colorizing task to a later date..
 				$COLORIZE_TIMER->Stop;
 				$COLORIZE_TIMER->Start( $COLORIZE_TIMEOUT, Wx::wxTIMER_ONE_SHOT );
@@ -51,3 +56,22 @@ sub colorize {
 
 
 1;
+
+__END__
+
+=head1 NAME
+
+Padre::Plugin::Parrot::HL - An HL Colorizer
+
+=head1 AUTHOR
+
+Gabor Szabo L<http://szabgab.com/>
+
+Ahmad M. Zawawi C<< <ahmad.zawawi at gmail.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2008-2010 Padre Developers as in Parrot.pm
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
